@@ -12,18 +12,20 @@ try:
 except ImportError:
     babel = None
 
-try:
-    from flask_babel import get_locale
-except ImportError:
-    def get_locale():
+
+def get_locale():
+    try:
+        return babel.Locale('en')
+    except AttributeError:
+        # As babel is optional, we may raise an AttributeError accessing it
         raise ImproperlyConfigured(
-            'Could not load get_locale function from Flask-Babel. Either '
-            'install Flask-Babel or make a similar function and override it '
+            'Could not load get_locale function using Babel. Either '
+            'install Babel or make a similar function and override it '
             'in this module.'
         )
 
 
-def cast_locale(obj, locale):
+def cast_locale(obj, locale, attr):
     """
     Cast given locale to string. Supports also callbacks that return locales.
 
@@ -34,23 +36,29 @@ def cast_locale(obj, locale):
     """
     if callable(locale):
         try:
-            locale = locale()
+            locale = locale(obj, attr.key)
         except TypeError:
-            locale = locale(obj)
+            try:
+                locale = locale(obj)
+            except TypeError:
+                locale = locale()
     if isinstance(locale, babel.Locale):
         return str(locale)
     return locale
 
 
 class cast_locale_expr(ColumnElement):
-    def __init__(self, cls, locale):
+    inherit_cache = False
+
+    def __init__(self, cls, locale, attr):
         self.cls = cls
         self.locale = locale
+        self.attr = attr
 
 
 @compiles(cast_locale_expr)
 def compile_cast_locale_expr(element, compiler, **kw):
-    locale = cast_locale(element.cls, element.locale)
+    locale = cast_locale(element.cls, element.locale, element.attr)
     if isinstance(locale, six.string_types):
         return "'{0}'".format(locale)
     return compiler.process(locale)
@@ -74,13 +82,11 @@ class TranslationHybrid(object):
         is no translation found for default locale it returns None.
         """
         def getter(obj):
-            current_locale = cast_locale(obj, self.current_locale)
+            current_locale = cast_locale(obj, self.current_locale, attr)
             try:
                 return getattr(obj, attr.key)[current_locale]
             except (TypeError, KeyError):
-                default_locale = cast_locale(
-                    obj, self.default_locale
-                )
+                default_locale = cast_locale(obj, self.default_locale, attr)
                 try:
                     return getattr(obj, attr.key)[default_locale]
                 except (TypeError, KeyError):
@@ -91,15 +97,15 @@ class TranslationHybrid(object):
         def setter(obj, value):
             if getattr(obj, attr.key) is None:
                 setattr(obj, attr.key, {})
-            locale = cast_locale(obj, self.current_locale)
+            locale = cast_locale(obj, self.current_locale, attr)
             getattr(obj, attr.key)[locale] = value
         return setter
 
     def expr_factory(self, attr):
         def expr(cls):
             cls_attr = getattr(cls, attr.key)
-            current_locale = cast_locale_expr(cls, self.current_locale)
-            default_locale = cast_locale_expr(cls, self.default_locale)
+            current_locale = cast_locale_expr(cls, self.current_locale, attr)
+            default_locale = cast_locale_expr(cls, self.default_locale, attr)
             return sa.func.coalesce(
                 cls_attr[current_locale],
                 cls_attr[default_locale]
